
# Slot: causal_associations

The causal associations that flow out of this activity

URI: [gocam:activity__causal_associations](https://w3id.org/gocam/activity__causal_associations)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [CausalAssociation](CausalAssociation.md)

## Parents


## Children


## Used by

 * [Activity](Activity.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | All activities in a model must be connected to at least one other activity. If a an activity has no outgoing activities (i.e the value of this slot is empty) then it is a terminal activity in the model. If an activity has no incoming activities, it is an initial activity. |
